==> nextcloud-app-spreed-1%3a6.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ja.js <==
OC.L10N.register(
    "spreed",
    {
    "New conversation …" : "新規公話",
    "Participants" : "参加者",
    "Chat" : "チャット",
    "Talk" : "通話",
    "Exit fullscreen (f)" : "全画面終了 (f)",
    "Fullscreen (f)" : "全画面 (f)",
    "Copy" : "コピー",
    "Copied!" : "コピーしました",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-C でコピーします。",
    "Share" : "共有",
    "Request password" : "パスワードを入力",
    "Please enter the password for this call" : "この通話のパスワードを入力してください",
    "Password required" : "パスワードが必要です",
    "Password" : "パスワード",
    "Cancel" : "キャンセル",
    "Submit" : "了解",
    "Leave call" : "通話終了",
    "Join call" : "通話開始",
    "Start call" : "通話を開始",
    "Share link" : "リンクの共有",
    "Change password" : "パスワード変更",
    "Set password" : "パスワード設定",
    "Name" : "名前",
    "Conversation name" : "会話の名前",
    "Rename" : "名前変更",
    "Copy link" : "リンクをコピー",
    "Conversation with {name}" : "{name} と会話",
    "Error occurred while setting password" : "パスワード設定中にエラーが発生しました",
    "Link copied!" : "リンクをコピーしました",
    "You" : "自分",
    "No messages yet, start the conversation!" : "まだメッセージはありません。会話を開始しましょう",
    "New message …" : "新しいメッセージ …",
    "Send" : "送信",
    "Guest" : "ゲスト",
    "[Unknown user name]" : "[不明なユーザー名]",
    "Today" : "本日",
    "Yesterday" : "昨日",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "メッセージ送信中にエラーが発生しました",
    "File to share" : "共有するファイル",
    "Error while sharing" : "共有でエラーが発生しました",
    "Edit" : "編集",
    "Join a conversation or start a new one" : "会話に参加または開始する",
    "No other people in this call" : "この通話には誰もいません",
    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
    "Waiting for others to join the call …" : "参加を待っています …",
    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
    "This conversation has ended" : "会話は終了しました",
    "Mute audio" : "音声なし",
    "Disable video" : "映像なし",
    "Share screen" : "画面共有",
    "Share whole screen" : "全画面共有",
    "Share a single window" : "ウィンドウを共有",
    "Show your screen" : "自分の画面を表示",
    "Stop screensharing" : "画面共有を停止",
    "Mute audio (m)" : "ミュート (m)",
    "Unmute audio (m)" : "ミュート解除 (m)",
    "No audio" : "音声なし",
    "Disable video (v)" : "映像なし (v)",
    "Enable video (v)" : "映像あり (v)",
    "No Camera" : "カメラがありません",
    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
    "Screensharing options" : "画面共有オプション",
    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
    "Enable screensharing" : "画面共有を有効にする",
    "moderator" : "モデレータ",
    "Demote from moderator" : "モデレータから降格",
    "Promote to moderator" : "モデレータに昇格",
    "Remove participant" : "参加者を削除",
    "Add participant …" : "参加者を追加",
    "Favorited" : "お気に入り済",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Always notify" : "常に通知する",
    "Leave conversation" : "会話を離れる",
    "Delete conversation" : "会話を削除",
    "Your screen" : "自画面",
    "{participantName}'s screen" : "{participantName} の画面",
    "Guest's screen" : "ゲストの画面",
    "Close" : "閉じる",
    "Show screen" : "画面を表示",
    "Enable video" : "動画を有効にする",
    "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
    "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
    "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
    "WebRTC is not supported in your browser" : "このブラウザーはWebRTCをサポートしていません",
    "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
    "a conversation" : "会話",
    "(Duration %s)" : "(%s 期限)",
    "You attended a call with {user1}" : "{user1} との通話に参加しました",
    "_%n guest_::_%n guests_" : ["ゲスト %n 名"],
    "You attended a call with {user1} and {user2}" : "{user1} と {user2} の通話に参加しました",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}、{user2} と {user3} の通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}、{user2}、 {user3} と {user4} の通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}、{user2}、{user3}、{user4} と {user5} の通話に参加しました",
    "_%n other_::_%n others_" : ["他 %n 名"],
    "{actor} invited you to {call}" : "{actor} から {call} に招待されました",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong>招待</strong>または、<strong>着信</strong>がありました。",
    "{actor} created the conversation" : "{actor} が会話を作成しました",
    "You created the conversation" : "会話を作成しました",
    "You started a call" : "通話を開始しました",
    "You joined the call" : "あなたはこの通話に参加しました",
    "{actor} left the call" : "{actor} が通話を離脱しました",
    "You left the call" : "あなたはこの通話を離脱しました",
    "{actor} allowed guests" : "{actor} がゲストを許可しました",
    "You allowed guests" : "あなたがゲストを許可しました",
    "You set a password" : "パスワードを設定する",
    "Talk to %s" : "%s と通話",
    "{user} wants to talk with you" : "{user} からの通話要請があります",
    "A group call has started in {call}" : "{call} のグループ通話が開始されました",
    "TURN server URL" : "TURN server URL",
    "Validate SSL certificate" : "SSL証明書を検証する",
    "STUN server URL" : "STUN server URL",
    "TURN server protocols" : "TURNサーバープロトコル",
    "UDP and TCP" : "UDP と TCP",
    "UDP only" : "UDP のみ",
    "TCP only" : "TCP のみ",
    "Save changes" : "変更を保存",
    "Saved" : "保存しました",
    "Shared secret" : "共有秘密鍵",
    "STUN servers" : "STUNサーバー",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーは、ルーターを介した参加者のパブリックIPアドレスを決定するために使用されます。",
    "The password is wrong. Try again." : "パスワードが違います。再入力してください",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "大規模に使用する場合は、オプションで外部のシグナリングサーバーを設定できます。内部のシグナリングサーバーを利用するには、空欄のままにしてください。",
    "TURN server" : "TURNサーバー",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURNサーバーは参加者のファイアウォール越しの通信を中継します。",
    "Join conversations at any time, any where, on any device." : "いつでも、どこでも、どのデバイスでも会話に参加できます。",
    "Signaling server URL" : "シグナリングサーバーURL",
    "Delete server" : "サーバーを削除",
    "Add new server" : "新しいサーバーを追加",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "すべてのSTUNサーバーは削除されましたが、STUNサーバーは必要なのでデフォルトサーバーが設定されました。",
    "TURN server shared secret" : "TURNサーバーの共有秘密鍵",
    "Test server" : "テストサーバー",
    "New public conversation" : "新規公開会話",
    "New group conversation" : "新規会議",
    "_%n other guest_::_%n other guests_" : ["他のゲスト %n 名"],
    ", " : "、",
    "A group call has started" : "グループ通話が開始されました",
    "This call is password-protected" : "この通話はパスワードで保護されています",
    "Signaling server" : "シグナリングサーバー"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3a6.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ja.js <==
OC.L10N.register(
    "spreed",
    {
    "New conversation …" : "新規公話",
    "Participants" : "参加者",
    "Chat" : "チャット",
    "Talk" : "通話",
    "Exit fullscreen (f)" : "全画面終了 (f)",
    "Fullscreen (f)" : "全画面 (f)",
    "Copy" : "コピー",
    "Copied!" : "コピーしました",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-C でコピーします。",
    "Share" : "共有",
    "Request password" : "パスワードを入力",
    "Please enter the password for this call" : "この通話のパスワードを入力してください",
    "Password required" : "パスワードが必要です",
    "Password" : "パスワード",
    "Cancel" : "キャンセル",
    "Submit" : "了解",
    "Leave call" : "通話終了",
    "Join call" : "通話開始",
    "Start call" : "通話を開始",
    "Share link" : "リンクの共有",
    "Change password" : "パスワード変更",
    "Set password" : "パスワード設定",
    "Name" : "名前",
    "Conversation name" : "会話の名前",
    "Rename" : "名前変更",
    "Copy link" : "リンクをコピー",
    "Conversation with {name}" : "{name} と会話",
    "Error occurred while setting password" : "パスワード設定中にエラーが発生しました",
    "Link copied!" : "リンクをコピーしました",
    "You" : "自分",
    "No messages yet, start the conversation!" : "まだメッセージはありません。会話を開始しましょう",
    "New message …" : "新しいメッセージ …",
    "Send" : "送信",
    "Guest" : "ゲスト",
    "[Unknown user name]" : "[不明なユーザー名]",
    "Today" : "本日",
    "Yesterday" : "昨日",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "メッセージ送信中にエラーが発生しました",
    "File to share" : "共有するファイル",
    "Error while sharing" : "共有でエラーが発生しました",
    "Edit" : "編集",
    "Join a conversation or start a new one" : "会話に参加または開始する",
    "No other people in this call" : "この通話には誰もいません",
    "Waiting for {participantName} to join the call …" : "{participantName} の参加を待っています …",
    "Waiting for others to join the call …" : "参加を待っています …",
    "You can invite others in the participant tab of the sidebar" : "サイドバーの参加者タブで他のユーザーを招待できます",
    "Share this link to invite others!" : "このリンクを共有して他の人を招待します。",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "サイドバーの参加者タブかこのリンクを共有して他のユーザーを招待できます。",
    "WebRTC is not supported in your browser :-/" : "このブラウザーはWebRTCをサポートしていません",
    "Please use a different browser like Firefox or Chrome" : "別のブラウザー（Firefox または Chrome 等）を使用してください",
    "Waiting for camera and microphone permissions" : "カメラとマイクの許可待ち",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "ブラウザーでカメラとマイクへのアクセスを許可してください。",
    "This conversation has ended" : "会話は終了しました",
    "Mute audio" : "音声なし",
    "Disable video" : "映像なし",
    "Share screen" : "画面共有",
    "Share whole screen" : "全画面共有",
    "Share a single window" : "ウィンドウを共有",
    "Show your screen" : "自分の画面を表示",
    "Stop screensharing" : "画面共有を停止",
    "Mute audio (m)" : "ミュート (m)",
    "Unmute audio (m)" : "ミュート解除 (m)",
    "No audio" : "音声なし",
    "Disable video (v)" : "映像なし (v)",
    "Enable video (v)" : "映像あり (v)",
    "No Camera" : "カメラがありません",
    "Screensharing is not supported by your browser." : "あなたのブラウザーは画面共有をサポートしていません。",
    "Screensharing requires the page to be loaded through HTTPS." : "画面共有はHTTPSが必要です。",
    "Screensharing options" : "画面共有オプション",
    "Sharing your screen only works with Firefox version 52 or newer." : "画面共有はFirefox バージョン52以上のみで動作します。",
    "Screensharing extension is required to share your screen." : "画面共有を利用するには画面共有エクステンションが必要です。",
    "Please use a different browser like Firefox or Chrome to share your screen." : "画面共有を利用する場合は、別のブラウザー（Firefox または Chrome 等）を使用してください。",
    "An error occurred while starting screensharing." : "画面共有の開始中にエラーが発生しました。",
    "Enable screensharing" : "画面共有を有効にする",
    "moderator" : "モデレータ",
    "Demote from moderator" : "モデレータから降格",
    "Promote to moderator" : "モデレータに昇格",
    "Remove participant" : "参加者を削除",
    "Add participant …" : "参加者を追加",
    "Favorited" : "お気に入り済",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Leave conversation" : "会話を離れる",
    "Delete conversation" : "会話を削除",
    "Your screen" : "自画面",
    "{participantName}'s screen" : "{participantName} の画面",
    "Guest's screen" : "ゲストの画面",
    "Close" : "閉じる",
    "Show screen" : "画面を表示",
    "Enable video" : "動画を有効にする",
    "Access to microphone & camera is only possible with HTTPS" : "マイクとカメラへのアクセスはHTTPSでのみ可能です",
    "Please move your setup to HTTPS" : "HTTPSを使用して設定してください",
    "Access to microphone & camera was denied" : "マイクとカメラへのアクセスが拒否されました",
    "WebRTC is not supported in your browser" : "このブラウザーはWebRTCをサポートしていません",
    "Error while accessing microphone & camera" : "マイクとカメラのアクセス中にエラーが発生しました",
    "a conversation" : "会話",
    "(Duration %s)" : "(%s 期限)",
    "You attended a call with {user1}" : "{user1} との通話に参加しました",
    "_%n guest_::_%n guests_" : ["ゲスト %n 名"],
    "You attended a call with {user1} and {user2}" : "{user1} と {user2} の通話に参加しました",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}、{user2} と {user3} の通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}、{user2}、 {user3} と {user4} の通話に参加しました",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}、{user2}、{user3}、{user4} と {user5} の通話に参加しました",
    "_%n other_::_%n others_" : ["他 %n 名"],
    "{actor} invited you to {call}" : "{actor} から {call} に招待されました",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong>招待</strong>または、<strong>着信</strong>がありました。",
    "{actor} created the conversation" : "{actor} が会話を作成しました",
    "You created the conversation" : "会話を作成しました",
    "You started a call" : "通話を開始しました",
    "You joined the call" : "あなたはこの通話に参加しました",
    "{actor} left the call" : "{actor} が通話を離脱しました",
    "You left the call" : "あなたはこの通話を離脱しました",
    "{actor} allowed guests" : "{actor} がゲストを許可しました",
    "You allowed guests" : "あなたがゲストを許可しました",
    "You set a password" : "パスワードを設定する",
    "Talk to %s" : "%s と通話",
    "{user} wants to talk with you" : "{user} からの通話要請があります",
    "A group call has started in {call}" : "{call} のグループ通話が開始されました",
    "TURN server URL" : "TURN server URL",
    "Validate SSL certificate" : "SSL証明書を検証する",
    "STUN server URL" : "STUN server URL",
    "TURN server protocols" : "TURNサーバープロトコル",
    "UDP and TCP" : "UDP と TCP",
    "UDP only" : "UDP のみ",
    "TCP only" : "TCP のみ",
    "Save changes" : "変更を保存",
    "Saved" : "保存しました",
    "Shared secret" : "共有秘密鍵",
    "STUN servers" : "STUNサーバー",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUNサーバーは、ルーターを介した参加者のパブリックIPアドレスを決定するために使用されます。",
    "The password is wrong. Try again." : "パスワードが違います。再入力してください",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "大規模に使用する場合は、オプションで外部のシグナリングサーバーを設定できます。内部のシグナリングサーバーを利用するには、空欄のままにしてください。",
    "TURN server" : "TURNサーバー",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURNサーバーは参加者のファイアウォール越しの通信を中継します。",
    "Join conversations at any time, any where, on any device." : "いつでも、どこでも、どのデバイスでも会話に参加できます。",
    "Signaling server URL" : "シグナリングサーバーURL",
    "Delete server" : "サーバーを削除",
    "Add new server" : "新しいサーバーを追加",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "すべてのSTUNサーバーは削除されましたが、STUNサーバーは必要なのでデフォルトサーバーが設定されました。",
    "TURN server shared secret" : "TURNサーバーの共有秘密鍵",
    "Test server" : "テストサーバー",
    "New public conversation" : "新規公開会話",
    "New group conversation" : "新規会議",
    "_%n other guest_::_%n other guests_" : ["他のゲスト %n 名"],
    ", " : "、",
    "A group call has started" : "グループ通話が開始されました",
    "This call is password-protected" : "この通話はパスワードで保護されています",
    "Signaling server" : "シグナリングサーバー",
    "Always notify" : "常に通知する"
},
"nplurals=1; plural=0;");
